import "Turbine";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Extensions";
import "Turbine.UI.Lotro";
import "Turbine.Utils";

Notes2Window = class( Turbine.UI.Lotro.Window );

function Notes2Window:Constructor()

	Notes2Window:LoadNote();
	current_type = 'character';
	Turbine.UI.Lotro.Window.Constructor( self );
	self:SetVisible( true );
	self:SetSize( 360, 400 );
	self:SetBackColor( Turbine.UI.Color() );
	self:SetPosition( 20, 220 );
	self:SetText( "Simply Notes" );
	self:SetOpacity( 0.6 );
	

	local Notes2 = self;
	local mainWindow = self;

	self.itemListBoxScrollBar = Turbine.UI.Lotro.ScrollBar();
	self.itemListBoxScrollBar:SetOrientation( Turbine.UI.Orientation.Vertical );
	self.itemListBoxScrollBar:SetParent( self );

	self.itemListBox = Turbine.UI.Lotro.TextBox();
	self.itemListBox:SetFont( Turbine.UI.Lotro.Font.Verdana14 );
	self.itemListBox:SetText( self.note_character.Note_Account );
	self.itemListBox:SetParent( self );
	self.itemListBox:SetVerticalScrollBar( self.itemListBoxScrollBar );
	

	self.resizeHandle = Turbine.UI.Control();
	self.resizeHandle:SetParent( self );
	self.resizeHandle:SetZOrder( 100 );
	self.resizeHandle:SetSize( 20, 20 );
	self.resizeHandle:SetPosition( self:GetWidth() - self.resizeHandle:GetWidth(), self:GetHeight() - self.resizeHandle:GetHeight() );

	self.resizeHandle.MouseDown = function( sender, args )
		sender.dragStartX = args.X;
		sender.dragStartY = args.Y;
		sender.dragging = true;
	end

	self.resizeHandle.MouseMove = function( sender, args )
		local width, height = mainWindow:GetSize();
		if ( sender.dragging ) then
			if(width >=240 and height >=170) then
				mainWindow:SetSize( width + ( args.X - sender.dragStartX ), height + ( args.Y - sender.dragStartY ) );
				sender:SetPosition( mainWindow:GetWidth() - sender:GetWidth(), mainWindow:GetHeight() - sender:GetHeight() )
			else
				if(width >240) then
					mainWindow:SetSize( width, 170);
				elseif(height >170) then
					mainWindow:SetSize( 240, height);
				else 
					mainWindow:SetSize( 240, 170);
				end
				sender:SetPosition( mainWindow:GetWidth() - sender:GetWidth(), mainWindow:GetHeight() - sender:GetHeight() )
				sender.dragging = false;
			end
			Notes2:PerformLayout()
		end
	end

	self.resizeHandle.MouseUp = function( sender, args )
		sender.dragging = false;
	end

	self.Closed = function( sender, args )
		Notes2Window:SaveNote(self.itemListBox:GetText(), current_type);
		self:SetVisible( false );
		Turbine.Shell.WriteLine( 'Notes Closed & Saved [ To open again type: /notes ]' );
	end
	
	self.MouseEnter = function( sender, args )
		sender:SetOpacity( 1 );
	end

	self.MouseLeave = function( sender, args )
		sender:SetOpacity( 0.6 );
	end
	
	self.FocusLost = function( sender, args )
		Notes2Window:SaveNote(self.itemListBox:GetText(), current_type);
	end
	
	self.noteLabel = Turbine.UI.Label();
	self.noteLabel:SetParent( self );
	self.noteLabel:SetText( "Note Type: Current Character" );
	self.noteLabel:SetPosition( 20, 40 );
	self.noteLabel:SetSize(200, 30 );
	
	self.charButton = Turbine.UI.Lotro.Button();
	self.charButton:SetParent( self );
	self.charButton:SetSize( 55, 20 );
	self.charButton:SetText( "Char" );
	
	self.serverButton = Turbine.UI.Lotro.Button();
	self.serverButton:SetParent( self );
	self.serverButton:SetSize( 60, 20 );
	self.serverButton:SetText( "Server" );

	
	
	

	
	
	self.charButton.Click = function( sender, args )
		Notes2Window:SaveNote(self.itemListBox:GetText(), current_type);
		self.itemListBox:SetText( self.note_character.Note_Account );
		current_type = 'character';
		self.noteLabel:SetText( "Note Type: Current Character" );
	end
	
	self.serverButton.Click = function( sender, args )
		Notes2Window:SaveNote(self.itemListBox:GetText(), current_type);
		self.itemListBox:SetText( self.note_server.Note_Account );
		current_type = 'server';
		self.noteLabel:SetText( "Note Type: Current Server" );
	end
	

	
	self:Refresh();
end

function Notes2Window:Refresh()
	self:PerformLayout();
end

function Notes2Window:PerformLayout()
	self:Layout( { } )
end

function Notes2Window:Layout( args )
	local width, height = self:GetSize();
	
	local listWidth = width - 40;
	local listHeight = height - 100;

	self.itemListBox:SetPosition( 15, 55 );
	self.itemListBox:SetSize( listWidth, listHeight );
	
	self.itemListBoxScrollBar:SetPosition( width - 25, 55 );
	self.itemListBoxScrollBar:SetSize( 10, listHeight );
	
	self.serverButton:SetPosition( width - listWidth/2 - 35, listHeight + 60 );
	
	self.charButton:SetPosition( width - listWidth/2 - 95, listHeight + 60 );
	
	

end

-- LOAD THE NOTE DATA
function Notes2Window:LoadNote()
	self.note_character = Turbine.PluginData.Load( Turbine.DataScope.Character, "Notes2Settings" );
	self.note_server = Turbine.PluginData.Load( Turbine.DataScope.Server, "Notes2Settings" );

	if ( type( self.note_character ) ~= "table" ) then
		self.note_character = { };
	end
	if ( type( self.note_server ) ~= "table" ) then
		self.note_server = { };
	end
	
	if ( not self.note_character.Note_Account ) then
		self.note_character.Note_Account = 'Insert Character Notes Here...';
	end
	
	if ( not self.note_server.Note_Account ) then
		self.note_server.Note_Account = 'Insert Server Notes Here...';
	end
	
	
	
end
-- SAVE THE NOTE DATA
function Notes2Window:SaveNote(data, typenote)
	if(typenote == 'character') then	
		self.note_character.Note_Account = data;
		Turbine.PluginData.Save( Turbine.DataScope.Character, "Notes2Settings", self.note_character );
	elseif(typenote == 'server') then
		self.note_server.Note_Account = data;
		Turbine.PluginData.Save( Turbine.DataScope.Server, "Notes2Settings", self.note_server );
	else
		Turbine.Shell.WriteLine( "Failed to send notetype." );
	end
	
end

